UploadCapabilityObserver class

Inheritance

Constructors

UploadCapabilityObserver({required BleSerial bleSerial})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → UploadCapabilityState
no setteroverride
stateStream → Stream<UploadCapabilityState>
no setterinherited

Methods

canNotifyState() → bool
inherited
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyState(UploadCapabilityState state) → void
inherited
start({required bool uploadEnabled}) → void
stop() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited