UploadState class

Inheritance

Constructors

UploadState({UploadStatus status = UploadStatus.idle, Error error = Error.unknown, double progress = 0.0})

Properties

error ↔ Error
getter/setter pairinherited
errorCode ↔ int
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
progress ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ UploadStatus
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited