Uploader class

Inheritance

Constructors

Uploader({required BleConnector bleConnector, required BleSerial bleSerial, int? maxMtuSize = null, int? maxBufferSize = null, bool sequentialUpload = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → UploadState
no setteroverride
stateStream → Stream<UploadState>
no setterinherited

Methods

canNotifyState() → bool
inherited
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyState(UploadState state) → void
inherited
toString() → String
A string representation of this object.
inherited
upload({required Uint8List firmwareData, Uint8List? signatureData, int? firmwareCrc, int? decompressedSize}) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited