BeginReq class

Inheritance

Constructors

BeginReq({required int firmwareSize, required int packageSize, required int bufferSize, required int compressedSize, required BeginReqFlags flags})

Properties

bufferSize → int
final
compressedSize → int
final
firmwareSize → int
final
flags → BeginReqFlags
final
hashCode → int
The hash code for this object.
no setterinherited
finalinherited
packageSize → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited