ErrorInd class

Inheritance

Constructors

ErrorInd({required int code})
ErrorInd.fromBytes(Uint8List data)
factory

Properties

code → int
final
hashCode → int
The hash code for this object.
no setterinherited
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited