RemoteInfoReader class

Inheritance

Constructors

RemoteInfoReader()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → RemoteInfoState
no setteroverride
stateStream → Stream<RemoteInfoState>
no setterinherited

Methods

canNotifyState() → bool
inherited
dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyState(RemoteInfoState state) → void
inherited
read(DeviceInfo deviceInfo, String manufacturesDictUrl) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited